@@ -1,7 +1,8 @@
 #!/usr/bin/env node
 
 // This is used as an example in the README for extra option features.
-// See also options-env.js for more extensive env examples.
+// See also options-env.js for more extensive env examples,
+// and options-conflicts.js for more details about .conflicts().
 
 // const { Command, Option } = require('commander'); // (normal include)
 const { Command, Option } = require('../'); // include commander in git clone of commander repo
@@ -12,7 +13,8 @@ program
   .addOption(new Option('-t, --timeout <delay>', 'timeout in seconds').default(60, 'one minute'))
   .addOption(new Option('-d, --drink <size>', 'drink cup size').choices(['small', 'medium', 'large']))
   .addOption(new Option('-p, --port <number>', 'port number').env('PORT'))
-  .addOption(new Option('--donate [amount]', 'optional donation in dollars').preset('20').argParser(parseFloat));
+  .addOption(new Option('--donate [amount]', 'optional donation in dollars').preset('20').argParser(parseFloat))
+  .addOption(new Option('--disable-server', 'disables the server').conflicts('port'));
 
 program.parse();
 
@@ -24,3 +26,4 @@ console.log('Options: ', program.opts());
 //    PORT=80 node options-extra.js
 //    node options-extra.js --donate
 //    node options-extra.js --donate 30.50
+//    node options-extra.js --disable-server --port 8000
